// Copyright 2022 Clayton Craft <clayton@craftyguy.net>
// SPDX-License-Identifier: GPL-3.0-or-later

package config

import (
	"fmt"
	"strings"
	"time"
)

type Type string

// Service types
const (
	TypeSimple  Type = "simple"
	TypeOneshot Type = "oneshot"
	TypeNotify  Type = "notify"
)

type Exec struct {
	Cmd           string
	Args          []string
	AllowedToFail bool
}

type ServiceConfig struct {
	Name            string
	Description     string
	Type            Type
	Restart         RestartCond
	RestartDur      time.Duration
	Env             map[string]string
	Before          []string
	After           []string
	Autostart       bool
	Path            string // path to the file that provided this config
	ExecStart       []Exec
	ExecStartPre    []Exec
	ExecStartPost   []Exec
	ExecOnFailure   []Exec
	StartLimitDur   time.Duration
	StartLimitBurst int
	TimeoutStartDur time.Duration
}

type RestartCond int

// Conditions for restarting the service
const (
	RestartAlways RestartCond = iota
	RestartFailure
	RestartSuccess
	RestartNever
)

func (e Exec) String() string {
	return fmt.Sprintf("Cmd: %s, Args: [%s]", e.Cmd, strings.Join(e.Args, ", "))
}
